==> com.liferay.layout.page.template.service-2.1.60-sources.jar: com/liferay/layout/page/template/internal/security/permission/resource/LayoutPageTemplatePortletResourcePermission.java <==
/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.layout.page.template.internal.security.permission.resource;

import com.liferay.exportimport.kernel.staging.permission.StagingPermission;
import com.liferay.layout.admin.constants.LayoutAdminPortletKeys;
import com.liferay.layout.page.template.constants.LayoutPageTemplateConstants;
import com.liferay.portal.kernel.model.Group;
import com.liferay.portal.kernel.security.auth.PrincipalException;
import com.liferay.portal.kernel.security.permission.PermissionChecker;
import com.liferay.portal.kernel.security.permission.resource.PortletResourcePermission;
import com.liferay.portal.kernel.security.permission.resource.PortletResourcePermissionFactory;
import com.liferay.portal.kernel.security.permission.resource.StagedPortletPermissionLogic;
import com.liferay.portal.kernel.service.GroupLocalService;
import com.liferay.staging.StagingGroupHelper;
import com.liferay.staging.StagingGroupHelperUtil;

import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Pavel Savinov
 */
@Component(
	immediate = true,
	property = "resource.name=" + LayoutPageTemplateConstants.RESOURCE_NAME,
	service = {
		LayoutPageTemplatePortletResourcePermission.class,
		PortletResourcePermission.class
	}
)
public class LayoutPageTemplatePortletResourcePermission
	implements PortletResourcePermission {

	@Activate
	public void activate() {
		_portletResourcePermission = PortletResourcePermissionFactory.create(
			LayoutPageTemplateConstants.RESOURCE_NAME,
			new StagedPortletPermissionLogic(
				_stagingPermission, LayoutAdminPortletKeys.GROUP_PAGES));
	}

	@Override
	public void check(
			PermissionChecker permissionChecker, Group group, String actionId)
		throws PrincipalException {

		if (!contains(
				permissionChecker, _getGroupId(group.getGroupId()), actionId)) {

			throw new PrincipalException();
		}
	}

	@Override
	public void check(
			PermissionChecker permissionChecker, long groupId, String actionId)
		throws PrincipalException {

		if (!contains(permissionChecker, _getGroupId(groupId), actionId)) {
			throw new PrincipalException();
		}
	}

	@Override
	public boolean contains(
		PermissionChecker permissionChecker, Group group, String actionId) {

		return contains(
			permissionChecker, _getGroupId(group.getGroupId()), actionId);
	}

	@Override
	public boolean contains(
		PermissionChecker permissionChecker, long groupId, String actionId) {

		return _portletResourcePermission.contains(
			permissionChecker, _getGroupId(groupId), actionId);
	}

	@Override
	public String getResourceName() {
		return LayoutPageTemplateConstants.RESOURCE_NAME;
	}

	private long _getGroupId(long groupId) {
		Group group = _groupLocalService.fetchGroup(groupId);

		if (group == null) {
			return groupId;
		}

		StagingGroupHelper stagingGroupHelper =
			StagingGroupHelperUtil.getStagingGroupHelper();

		if (stagingGroupHelper.isLocalLiveGroup(groupId)) {
			Group stagingGroup = group.getStagingGroup();

			return stagingGroup.getGroupId();
		}

		return groupId;
	}

	@Reference
	private GroupLocalService _groupLocalService;

	private PortletResourcePermission _portletResourcePermission;

	@Reference
	private StagingPermission _stagingPermission;

}

==> com.liferay.layout.page.template.service-3.0.87-sources.jar: com/liferay/layout/page/template/internal/security/permission/resource/LayoutPageTemplatePortletResourcePermission.java <==
/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.layout.page.template.internal.security.permission.resource;

import com.liferay.exportimport.kernel.staging.permission.StagingPermission;
import com.liferay.layout.page.template.admin.constants.LayoutPageTemplateAdminPortletKeys;
import com.liferay.layout.page.template.constants.LayoutPageTemplateConstants;
import com.liferay.portal.kernel.model.Group;
import com.liferay.portal.kernel.security.auth.PrincipalException;
import com.liferay.portal.kernel.security.permission.PermissionChecker;
import com.liferay.portal.kernel.security.permission.resource.PortletResourcePermission;
import com.liferay.portal.kernel.security.permission.resource.PortletResourcePermissionFactory;
import com.liferay.portal.kernel.security.permission.resource.StagedPortletPermissionLogic;
import com.liferay.portal.kernel.service.GroupLocalService;
import com.liferay.staging.StagingGroupHelper;
import com.liferay.staging.StagingGroupHelperUtil;

import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Pavel Savinov
 */
@Component(
	immediate = true,
	property = "resource.name=" + LayoutPageTemplateConstants.RESOURCE_NAME,
	service = {
		LayoutPageTemplatePortletResourcePermission.class,
		PortletResourcePermission.class
	}
)
public class LayoutPageTemplatePortletResourcePermission
	implements PortletResourcePermission {

	@Override
	public void check(
			PermissionChecker permissionChecker, Group group, String actionId)
		throws PrincipalException {

		if (!contains(
				permissionChecker, _getGroupId(group.getGroupId()), actionId)) {

			throw new PrincipalException();
		}
	}

	@Override
	public void check(
			PermissionChecker permissionChecker, long groupId, String actionId)
		throws PrincipalException {

		if (!contains(permissionChecker, _getGroupId(groupId), actionId)) {
			throw new PrincipalException();
		}
	}

	@Override
	public boolean contains(
		PermissionChecker permissionChecker, Group group, String actionId) {

		return contains(
			permissionChecker, _getGroupId(group.getGroupId()), actionId);
	}

	@Override
	public boolean contains(
		PermissionChecker permissionChecker, long groupId, String actionId) {

		return _portletResourcePermission.contains(
			permissionChecker, _getGroupId(groupId), actionId);
	}

	@Override
	public String getResourceName() {
		return LayoutPageTemplateConstants.RESOURCE_NAME;
	}

	@Activate
	protected void activate() {
		_portletResourcePermission = PortletResourcePermissionFactory.create(
			LayoutPageTemplateConstants.RESOURCE_NAME,
			new StagedPortletPermissionLogic(
				_stagingPermission,
				LayoutPageTemplateAdminPortletKeys.LAYOUT_PAGE_TEMPLATES));
	}

	private long _getGroupId(long groupId) {
		Group group = _groupLocalService.fetchGroup(groupId);

		if (group == null) {
			return groupId;
		}

		StagingGroupHelper stagingGroupHelper =
			StagingGroupHelperUtil.getStagingGroupHelper();

		if (stagingGroupHelper.isLocalLiveGroup(groupId)) {
			Group stagingGroup = group.getStagingGroup();

			return stagingGroup.getGroupId();
		}

		return groupId;
	}

	@Reference
	private GroupLocalService _groupLocalService;

	private PortletResourcePermission _portletResourcePermission;

	@Reference
	private StagingPermission _stagingPermission;

}
